@@ -20,16 +20,16 @@ def remove_background(img):
     return output
 
 
-def change_background(img, back_img):
+def change_background(img, back_img, return_as_np_array=True):
     back_removed_img = remove_background(img)
-    back = img
+    back = back_img
     if type(back_img) == bytes:
         back = Image.fromarray(np.uint8(cv2.cvtColor(parse_uploaded_file(back_img), cv2.COLOR_RGB2BGR)))
     if type(back_img) == str:
         with open(img, 'rb') as i:
             back = i.read()
     back.paste(back_removed_img, (0, 0), mask=back_removed_img)
-    return back
+    return cv2.cvtColor(np.asarray(back), cv2.COLOR_RGB2BGR)
 
 
 
